==> cxf-services-xkms-common-3.3.0-sources.jar: org/apache/cxf/xkms/model/xkms/RegisterRequestType.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for RegisterRequestType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RegisterRequestType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.w3.org/2002/03/xkms#}RequestAbstractType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}PrototypeKeyBinding"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}Authentication"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}ProofOfPossession" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RegisterRequestType", propOrder = {
    "prototypeKeyBinding",
    "authentication",
    "proofOfPossession"
})
public class RegisterRequestType
    extends RequestAbstractType
{

    @XmlElement(name = "PrototypeKeyBinding", required = true)
    protected PrototypeKeyBindingType prototypeKeyBinding = new PrototypeKeyBindingType();
    @XmlElement(name = "Authentication", required = true)
    protected AuthenticationType authentication = new AuthenticationType();
    @XmlElement(name = "ProofOfPossession")
    protected ProofOfPossessionType proofOfPossession;

    /**
     * Gets the value of the prototypeKeyBinding property.
     * 
     * @return
     *     possible object is
     *     {@link PrototypeKeyBindingType }
     *     
     */
    public PrototypeKeyBindingType getPrototypeKeyBinding() {
        return prototypeKeyBinding;
    }

    /**
     * Sets the value of the prototypeKeyBinding property.
     * 
     * @param value
     *     allowed object is
     *     {@link PrototypeKeyBindingType }
     *     
     */
    public void setPrototypeKeyBinding(PrototypeKeyBindingType value) {
        this.prototypeKeyBinding = value;
    }

    /**
     * Gets the value of the authentication property.
     * 
     * @return
     *     possible object is
     *     {@link AuthenticationType }
     *     
     */
    public AuthenticationType getAuthentication() {
        return authentication;
    }

    /**
     * Sets the value of the authentication property.
     * 
     * @param value
     *     allowed object is
     *     {@link AuthenticationType }
     *     
     */
    public void setAuthentication(AuthenticationType value) {
        this.authentication = value;
    }

    /**
     * Gets the value of the proofOfPossession property.
     * 
     * @return
     *     possible object is
     *     {@link ProofOfPossessionType }
     *     
     */
    public ProofOfPossessionType getProofOfPossession() {
        return proofOfPossession;
    }

    /**
     * Sets the value of the proofOfPossession property.
     * 
     * @param value
     *     allowed object is
     *     {@link ProofOfPossessionType }
     *     
     */
    public void setProofOfPossession(ProofOfPossessionType value) {
        this.proofOfPossession = value;
    }

}

==> cxf-services-xkms-common-3.3.12-sources.jar: org/apache/cxf/xkms/model/xkms/RegisterRequestType.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * &lt;p&gt;Java class for RegisterRequestType complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType name="RegisterRequestType"&amp;gt;
 *   &amp;lt;complexContent&amp;gt;
 *     &amp;lt;extension base="{http://www.w3.org/2002/03/xkms#}RequestAbstractType"&amp;gt;
 *       &amp;lt;sequence&amp;gt;
 *         &amp;lt;element ref="{http://www.w3.org/2002/03/xkms#}PrototypeKeyBinding"/&amp;gt;
 *         &amp;lt;element ref="{http://www.w3.org/2002/03/xkms#}Authentication"/&amp;gt;
 *         &amp;lt;element ref="{http://www.w3.org/2002/03/xkms#}ProofOfPossession" minOccurs="0"/&amp;gt;
 *       &amp;lt;/sequence&amp;gt;
 *     &amp;lt;/extension&amp;gt;
 *   &amp;lt;/complexContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RegisterRequestType", propOrder = {
    "prototypeKeyBinding",
    "authentication",
    "proofOfPossession"
})
public class RegisterRequestType
    extends RequestAbstractType
{

    @XmlElement(name = "PrototypeKeyBinding", required = true)
    protected PrototypeKeyBindingType prototypeKeyBinding = new PrototypeKeyBindingType();
    @XmlElement(name = "Authentication", required = true)
    protected AuthenticationType authentication = new AuthenticationType();
    @XmlElement(name = "ProofOfPossession")
    protected ProofOfPossessionType proofOfPossession;

    /**
     * Gets the value of the prototypeKeyBinding property.
     * 
     * @return
     *     possible object is
     *     {@link PrototypeKeyBindingType }
     *     
     */
    public PrototypeKeyBindingType getPrototypeKeyBinding() {
        return prototypeKeyBinding;
    }

    /**
     * Sets the value of the prototypeKeyBinding property.
     * 
     * @param value
     *     allowed object is
     *     {@link PrototypeKeyBindingType }
     *     
     */
    public void setPrototypeKeyBinding(PrototypeKeyBindingType value) {
        this.prototypeKeyBinding = value;
    }

    /**
     * Gets the value of the authentication property.
     * 
     * @return
     *     possible object is
     *     {@link AuthenticationType }
     *     
     */
    public AuthenticationType getAuthentication() {
        return authentication;
    }

    /**
     * Sets the value of the authentication property.
     * 
     * @param value
     *     allowed object is
     *     {@link AuthenticationType }
     *     
     */
    public void setAuthentication(AuthenticationType value) {
        this.authentication = value;
    }

    /**
     * Gets the value of the proofOfPossession property.
     * 
     * @return
     *     possible object is
     *     {@link ProofOfPossessionType }
     *     
     */
    public ProofOfPossessionType getProofOfPossession() {
        return proofOfPossession;
    }

    /**
     * Sets the value of the proofOfPossession property.
     * 
     * @param value
     *     allowed object is
     *     {@link ProofOfPossessionType }
     *     
     */
    public void setProofOfPossession(ProofOfPossessionType value) {
        this.proofOfPossession = value;
    }

}
